@@ -19,7 +19,7 @@ import uuid
 # third-party modules
 import requests
 
-__version__ = '1.1.16'
+__version__ = '1.1.17'
 logger = logging.getLogger(__name__)
 
 
@@ -458,7 +458,7 @@ def purgeKnownHost( host, port ):
         stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL
     )
     if retCode != 0:
-        logger.error( 'returnd error code %s', retCode )
+        logger.warning( 'returned error code %s for host %s', retCode, host )
 
 def purgeKnownHosts( inRecs ):
     for inRec in inRecs:
